@@ -1,4 +1,5 @@
 #' Quick data frame.
+#'
 #' Experimental version of \code{\link{as.data.frame}} that converts a 
 #' list to a data frame, but doesn't do any checks to make sure it's a
 #' valid format.  Much faster.
@@ -10,11 +11,19 @@ quickdf <- function(list) {
   rows <- unique(unlist(lapply(list, NROW)))
   stopifnot(length(rows) == 1)
   
-  if (is.null(names(list))) {
-    names(list) <- paste("X", seq_along(list), sep = "")
-  }
+  names(list) <- make_names(list, "X")
   
   structure(list, 
     class = "data.frame",
     row.names = seq_len(rows))
 }
+
+make_names <- function(x, prefix = "X") {
+  nm <- names(x)
+  if (is.null(nm)) {
+    nm <- rep("", length = length(x))
+  }
+  
+  nm[nm == ""] <- paste(prefix, seq_len(sum(nm == "")), sep = "")
+  nm
+}
\ No newline at end of file
