@@ -36,7 +36,7 @@
 #' llply(x, quantile, probs = 1:3/4)
 llply <- function(.data, .fun = NULL, ..., .progress = "none", .inform = FALSE, .parallel = FALSE) {
   if (is.null(.fun)) return(as.list(.data))
-  if (is.character(.fun)) .fun <- each(.fun)
+  if (is.character(.fun) || is.list(.fun)) .fun <- each(.fun)
   if (!is.function(.fun)) stop(".fun is not a function.")
 
   if (!inherits(.data, "split")) {
