@@ -12,4 +12,11 @@ test_that("Single name match makes change", {
   y <- rename(x, c(b = "c"))
   
   expect_equal(names(y), c("a", "c"))
+})
+
+test_that("Multiple names correctly changed", {
+  x <- c(a = 1, b = 2, c = 3)
+  y <- rename(x, c("c" = "f", "b" = "e", "a" = "d"))
+  
+  expect_equal(names(y), c("d", "e", "f"))
 })
\ No newline at end of file
